@@ -43,7 +43,7 @@ from util.dns import PROTO_UDP, PROTO_TCP, PROTO_TLS, PROTO_HTTPS, proto_to_text
 
 __author__ = 'Babak Farrokhi (babak@farrokhi.net)'
 __license__ = 'BSD'
-__version__ = '2.0.1'
+__version__ = '2.0.2'
 __progname__ = os.path.basename(sys.argv[0])
 shutdown = False
 
@@ -258,7 +258,7 @@ def main():
             response_time.append(elapsed)
             if not quiet:
                 if show_flags:
-                    flags = " [%s]" % dns.flags.to_text(answers.flags)
+                    flags = " [%s]  %s" % (dns.flags.to_text(answers.flags), dns.rcode.to_text(answers.rcode()))
                 else:
                     flags = ""
                 print("%d bytes from %s: seq=%-3d time=%.3f ms%s" % (
